﻿using System;
using System.Collections.Generic;
using System.Drawing;
using HeuristicLab.Common;
using HeuristicLab.Core;

namespace HeuristicLab.DataPreprocessing {

  [Item("DataGridContent", "Represents a data grid.")]
  public class DataGridContent : Item, IDataGridContent, IContent {

    private readonly IDataGridLogic dataGridLogic;
    public DataGridContent(IDataGridLogic theDataGridLogic) {
      dataGridLogic = theDataGridLogic;
    }

    public DataGridContent(DataGridContent dataGridContent, Cloner cloner)
      : base(dataGridContent, cloner) {

    }

    public IDataGridLogic DataGridLogic {
      get {
        return dataGridLogic;
      }
    }

    public static new Image StaticItemImage {
      get { return HeuristicLab.Common.Resources.VSImageLibrary.Table; }
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new DataGridContent(this, cloner);
    }

    public int Rows {
      get {
        return dataGridLogic.Rows;
      }
      set {
        //does nothing
      }
    }

    public int Columns {
      get {
        return dataGridLogic.Columns;
      }
      set {
        //does nothing
      }
    }

    public IEnumerable<string> ColumnNames {
      get {
        return dataGridLogic.ColumnNames;
      }
      set {

      }
    }

    public IEnumerable<string> RowNames {
      get {
        return dataGridLogic.RowNames;
      }
      set {
        //not supported
      }
    }

    public bool SortableView {
      get {
        return true;
      }
      set {
        //not supported
      }
    }

    public bool ReadOnly {
      get { return true; }
    }

    public bool Validate(string value, out string errorMessage) {
      errorMessage = string.Empty;
      return true;
    }

    public bool Validate(string value, out string errorMessage, int columnIndex) {
      return dataGridLogic.Validate(value, out errorMessage, columnIndex);
    }

    public string GetValue(int rowIndex, int columnIndex) {
      return dataGridLogic.GetValue(rowIndex, columnIndex);
    }

    public bool SetValue(string value, int rowIndex, int columnIndex) {
      return dataGridLogic.SetValue(value, rowIndex, columnIndex);
    }

    public event EventHandler ColumnsChanged;

    public event EventHandler RowsChanged;

    public event EventHandler ColumnNamesChanged;

    public event EventHandler RowNamesChanged;

    public event EventHandler SortableViewChanged;

    public event EventHandler<EventArgs<int, int>> ItemChanged;

    public event EventHandler Reset;

  }
}
